Learn R Programming

g6R (version 0.5.0)

g6_update_layout: Execute layout for a g6 graph via proxy

Description

This function order the execution of the layout of the current graph. It can also update layout options before running it.

Usage

g6_update_layout(graph, ...)

Value

The g6_proxy object (invisibly), allowing for method chaining.

Arguments

graph

A g6_proxy object created with g6_proxy.

...

Any option to pass to the layout. If so, the layout is updated before running it.

Details

This function can only be used with a g6_proxy object within a Shiny application. It will not work with regular g6 objects outside of Shiny.

See Also

g6_proxy