This function order the execution of the layout of the current graph. It can also update layout options before running it.
g6_update_layout(graph, ...)The g6_proxy object (invisibly), allowing for method chaining.
A g6_proxy object created with g6_proxy.
Any option to pass to the layout. If so, the layout is updated before running it.
This function can only be used with a g6_proxy object within a Shiny application. It will not work with regular g6 objects outside of Shiny.
g6_proxy